"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import opentelemetry.proto.resource.v1.resource_pb2
import typing
import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class MetricConfigRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    RESOURCE_FIELD_NUMBER: builtins.int
    LAST_KNOWN_FINGERPRINT_FIELD_NUMBER: builtins.int
    last_known_fingerprint: builtins.bytes = ...

    @property
    def resource(self) -> opentelemetry.proto.resource.v1.resource_pb2.Resource: ...

    def __init__(self,
        *,
        resource : typing.Optional[opentelemetry.proto.resource.v1.resource_pb2.Resource] = ...,
        last_known_fingerprint : builtins.bytes = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal[u"resource",b"resource"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"last_known_fingerprint",b"last_known_fingerprint",u"resource",b"resource"]) -> None: ...
global___MetricConfigRequest = MetricConfigRequest

class MetricConfigResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    class Schedule(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
        class Pattern(google.protobuf.message.Message):
            DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
            EQUALS_FIELD_NUMBER: builtins.int
            STARTS_WITH_FIELD_NUMBER: builtins.int
            equals: typing.Text = ...
            starts_with: typing.Text = ...

            def __init__(self,
                *,
                equals : typing.Text = ...,
                starts_with : typing.Text = ...,
                ) -> None: ...
            def HasField(self, field_name: typing_extensions.Literal[u"equals",b"equals",u"match",b"match",u"starts_with",b"starts_with"]) -> builtins.bool: ...
            def ClearField(self, field_name: typing_extensions.Literal[u"equals",b"equals",u"match",b"match",u"starts_with",b"starts_with"]) -> None: ...
            def WhichOneof(self, oneof_group: typing_extensions.Literal[u"match",b"match"]) -> typing_extensions.Literal["equals","starts_with"]: ...

        EXCLUSION_PATTERNS_FIELD_NUMBER: builtins.int
        INCLUSION_PATTERNS_FIELD_NUMBER: builtins.int
        PERIOD_SEC_FIELD_NUMBER: builtins.int
        period_sec: builtins.int = ...

        @property
        def exclusion_patterns(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___MetricConfigResponse.Schedule.Pattern]: ...

        @property
        def inclusion_patterns(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___MetricConfigResponse.Schedule.Pattern]: ...

        def __init__(self,
            *,
            exclusion_patterns : typing.Optional[typing.Iterable[global___MetricConfigResponse.Schedule.Pattern]] = ...,
            inclusion_patterns : typing.Optional[typing.Iterable[global___MetricConfigResponse.Schedule.Pattern]] = ...,
            period_sec : builtins.int = ...,
            ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal[u"exclusion_patterns",b"exclusion_patterns",u"inclusion_patterns",b"inclusion_patterns",u"period_sec",b"period_sec"]) -> None: ...

    FINGERPRINT_FIELD_NUMBER: builtins.int
    SCHEDULES_FIELD_NUMBER: builtins.int
    SUGGESTED_WAIT_TIME_SEC_FIELD_NUMBER: builtins.int
    fingerprint: builtins.bytes = ...
    suggested_wait_time_sec: builtins.int = ...

    @property
    def schedules(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___MetricConfigResponse.Schedule]: ...

    def __init__(self,
        *,
        fingerprint : builtins.bytes = ...,
        schedules : typing.Optional[typing.Iterable[global___MetricConfigResponse.Schedule]] = ...,
        suggested_wait_time_sec : builtins.int = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"fingerprint",b"fingerprint",u"schedules",b"schedules",u"suggested_wait_time_sec",b"suggested_wait_time_sec"]) -> None: ...
global___MetricConfigResponse = MetricConfigResponse



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import typing
import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class AnyValue(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    STRING_VALUE_FIELD_NUMBER: builtins.int
    BOOL_VALUE_FIELD_NUMBER: builtins.int
    INT_VALUE_FIELD_NUMBER: builtins.int
    DOUBLE_VALUE_FIELD_NUMBER: builtins.int
    ARRAY_VALUE_FIELD_NUMBER: builtins.int
    KVLIST_VALUE_FIELD_NUMBER: builtins.int
    BYTES_VALUE_FIELD_NUMBER: builtins.int
    string_value: typing.Text = ...
    bool_value: builtins.bool = ...
    int_value: builtins.int = ...
    double_value: builtins.float = ...
    bytes_value: builtins.bytes = ...

    @property
    def array_value(self) -> global___ArrayValue: ...

    @property
    def kvlist_value(self) -> global___KeyValueList: ...

    def __init__(self,
        *,
        string_value : typing.Text = ...,
        bool_value : builtins.bool = ...,
        int_value : builtins.int = ...,
        double_value : builtins.float = ...,
        array_value : typing.Optional[global___ArrayValue] = ...,
        kvlist_value : typing.Optional[global___KeyValueList] = ...,
        bytes_value : builtins.bytes = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal[u"array_value",b"array_value",u"bool_value",b"bool_value",u"bytes_value",b"bytes_value",u"double_value",b"double_value",u"int_value",b"int_value",u"kvlist_value",b"kvlist_value",u"string_value",b"string_value",u"value",b"value"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"array_value",b"array_value",u"bool_value",b"bool_value",u"bytes_value",b"bytes_value",u"double_value",b"double_value",u"int_value",b"int_value",u"kvlist_value",b"kvlist_value",u"string_value",b"string_value",u"value",b"value"]) -> None: ...
    def WhichOneof(self, oneof_group: typing_extensions.Literal[u"value",b"value"]) -> typing_extensions.Literal["string_value","bool_value","int_value","double_value","array_value","kvlist_value","bytes_value"]: ...
global___AnyValue = AnyValue

class ArrayValue(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    VALUES_FIELD_NUMBER: builtins.int

    @property
    def values(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___AnyValue]: ...

    def __init__(self,
        *,
        values : typing.Optional[typing.Iterable[global___AnyValue]] = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"values",b"values"]) -> None: ...
global___ArrayValue = ArrayValue

class KeyValueList(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    VALUES_FIELD_NUMBER: builtins.int

    @property
    def values(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___KeyValue]: ...

    def __init__(self,
        *,
        values : typing.Optional[typing.Iterable[global___KeyValue]] = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"values",b"values"]) -> None: ...
global___KeyValueList = KeyValueList

class KeyValue(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    KEY_FIELD_NUMBER: builtins.int
    VALUE_FIELD_NUMBER: builtins.int
    key: typing.Text = ...

    @property
    def value(self) -> global___AnyValue: ...

    def __init__(self,
        *,
        key : typing.Text = ...,
        value : typing.Optional[global___AnyValue] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal[u"value",b"value"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"key",b"key",u"value",b"value"]) -> None: ...
global___KeyValue = KeyValue

class StringKeyValue(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    KEY_FIELD_NUMBER: builtins.int
    VALUE_FIELD_NUMBER: builtins.int
    key: typing.Text = ...
    value: typing.Text = ...

    def __init__(self,
        *,
        key : typing.Text = ...,
        value : typing.Text = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"key",b"key",u"value",b"value"]) -> None: ...
global___StringKeyValue = StringKeyValue

class InstrumentationLibrary(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    NAME_FIELD_NUMBER: builtins.int
    VERSION_FIELD_NUMBER: builtins.int
    name: typing.Text = ...
    version: typing.Text = ...

    def __init__(self,
        *,
        name : typing.Text = ...,
        version : typing.Text = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"name",b"name",u"version",b"version"]) -> None: ...
global___InstrumentationLibrary = InstrumentationLibrary



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import opentelemetry.proto.metrics.v1.metrics_pb2
import typing
import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class ExportMetricsServiceRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    RESOURCE_METRICS_FIELD_NUMBER: builtins.int

    @property
    def resource_metrics(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[opentelemetry.proto.metrics.v1.metrics_pb2.ResourceMetrics]: ...

    def __init__(self,
        *,
        resource_metrics : typing.Optional[typing.Iterable[opentelemetry.proto.metrics.v1.metrics_pb2.ResourceMetrics]] = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"resource_metrics",b"resource_metrics"]) -> None: ...
global___ExportMetricsServiceRequest = ExportMetricsServiceRequest

class ExportMetricsServiceResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...

    def __init__(self,
        ) -> None: ...
global___ExportMetricsServiceResponse = ExportMetricsServiceResponse



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import opentelemetry.proto.common.v1.common_pb2
import opentelemetry.proto.resource.v1.resource_pb2
import typing
import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class ResourceSpans(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    RESOURCE_FIELD_NUMBER: builtins.int
    INSTRUMENTATION_LIBRARY_SPANS_FIELD_NUMBER: builtins.int
    SCHEMA_URL_FIELD_NUMBER: builtins.int
    schema_url: typing.Text = ...

    @property
    def resource(self) -> opentelemetry.proto.resource.v1.resource_pb2.Resource: ...

    @property
    def instrumentation_library_spans(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___InstrumentationLibrarySpans]: ...

    def __init__(self,
        *,
        resource : typing.Optional[opentelemetry.proto.resource.v1.resource_pb2.Resource] = ...,
        instrumentation_library_spans : typing.Optional[typing.Iterable[global___InstrumentationLibrarySpans]] = ...,
        schema_url : typing.Text = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal[u"resource",b"resource"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"instrumentation_library_spans",b"instrumentation_library_spans",u"resource",b"resource",u"schema_url",b"schema_url"]) -> None: ...
global___ResourceSpans = ResourceSpans

class InstrumentationLibrarySpans(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    INSTRUMENTATION_LIBRARY_FIELD_NUMBER: builtins.int
    SPANS_FIELD_NUMBER: builtins.int
    SCHEMA_URL_FIELD_NUMBER: builtins.int
    schema_url: typing.Text = ...

    @property
    def instrumentation_library(self) -> opentelemetry.proto.common.v1.common_pb2.InstrumentationLibrary: ...

    @property
    def spans(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___Span]: ...

    def __init__(self,
        *,
        instrumentation_library : typing.Optional[opentelemetry.proto.common.v1.common_pb2.InstrumentationLibrary] = ...,
        spans : typing.Optional[typing.Iterable[global___Span]] = ...,
        schema_url : typing.Text = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal[u"instrumentation_library",b"instrumentation_library"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"instrumentation_library",b"instrumentation_library",u"schema_url",b"schema_url",u"spans",b"spans"]) -> None: ...
global___InstrumentationLibrarySpans = InstrumentationLibrarySpans

class Span(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    class _SpanKind(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[SpanKind.V], builtins.type):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor = ...
        SPAN_KIND_UNSPECIFIED = Span.SpanKind.V(0)
        SPAN_KIND_INTERNAL = Span.SpanKind.V(1)
        SPAN_KIND_SERVER = Span.SpanKind.V(2)
        SPAN_KIND_CLIENT = Span.SpanKind.V(3)
        SPAN_KIND_PRODUCER = Span.SpanKind.V(4)
        SPAN_KIND_CONSUMER = Span.SpanKind.V(5)
    class SpanKind(metaclass=_SpanKind):
        V = typing.NewType('V', builtins.int)
    SPAN_KIND_UNSPECIFIED = Span.SpanKind.V(0)
    SPAN_KIND_INTERNAL = Span.SpanKind.V(1)
    SPAN_KIND_SERVER = Span.SpanKind.V(2)
    SPAN_KIND_CLIENT = Span.SpanKind.V(3)
    SPAN_KIND_PRODUCER = Span.SpanKind.V(4)
    SPAN_KIND_CONSUMER = Span.SpanKind.V(5)

    class Event(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
        TIME_UNIX_NANO_FIELD_NUMBER: builtins.int
        NAME_FIELD_NUMBER: builtins.int
        ATTRIBUTES_FIELD_NUMBER: builtins.int
        DROPPED_ATTRIBUTES_COUNT_FIELD_NUMBER: builtins.int
        time_unix_nano: builtins.int = ...
        name: typing.Text = ...
        dropped_attributes_count: builtins.int = ...

        @property
        def attributes(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[opentelemetry.proto.common.v1.common_pb2.KeyValue]: ...

        def __init__(self,
            *,
            time_unix_nano : builtins.int = ...,
            name : typing.Text = ...,
            attributes : typing.Optional[typing.Iterable[opentelemetry.proto.common.v1.common_pb2.KeyValue]] = ...,
            dropped_attributes_count : builtins.int = ...,
            ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal[u"attributes",b"attributes",u"dropped_attributes_count",b"dropped_attributes_count",u"name",b"name",u"time_unix_nano",b"time_unix_nano"]) -> None: ...

    class Link(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
        TRACE_ID_FIELD_NUMBER: builtins.int
        SPAN_ID_FIELD_NUMBER: builtins.int
        TRACE_STATE_FIELD_NUMBER: builtins.int
        ATTRIBUTES_FIELD_NUMBER: builtins.int
        DROPPED_ATTRIBUTES_COUNT_FIELD_NUMBER: builtins.int
        trace_id: builtins.bytes = ...
        span_id: builtins.bytes = ...
        trace_state: typing.Text = ...
        dropped_attributes_count: builtins.int = ...

        @property
        def attributes(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[opentelemetry.proto.common.v1.common_pb2.KeyValue]: ...

        def __init__(self,
            *,
            trace_id : builtins.bytes = ...,
            span_id : builtins.bytes = ...,
            trace_state : typing.Text = ...,
            attributes : typing.Optional[typing.Iterable[opentelemetry.proto.common.v1.common_pb2.KeyValue]] = ...,
            dropped_attributes_count : builtins.int = ...,
            ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal[u"attributes",b"attributes",u"dropped_attributes_count",b"dropped_attributes_count",u"span_id",b"span_id",u"trace_id",b"trace_id",u"trace_state",b"trace_state"]) -> None: ...

    TRACE_ID_FIELD_NUMBER: builtins.int
    SPAN_ID_FIELD_NUMBER: builtins.int
    TRACE_STATE_FIELD_NUMBER: builtins.int
    PARENT_SPAN_ID_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    KIND_FIELD_NUMBER: builtins.int
    START_TIME_UNIX_NANO_FIELD_NUMBER: builtins.int
    END_TIME_UNIX_NANO_FIELD_NUMBER: builtins.int
    ATTRIBUTES_FIELD_NUMBER: builtins.int
    DROPPED_ATTRIBUTES_COUNT_FIELD_NUMBER: builtins.int
    EVENTS_FIELD_NUMBER: builtins.int
    DROPPED_EVENTS_COUNT_FIELD_NUMBER: builtins.int
    LINKS_FIELD_NUMBER: builtins.int
    DROPPED_LINKS_COUNT_FIELD_NUMBER: builtins.int
    STATUS_FIELD_NUMBER: builtins.int
    trace_id: builtins.bytes = ...
    span_id: builtins.bytes = ...
    trace_state: typing.Text = ...
    parent_span_id: builtins.bytes = ...
    name: typing.Text = ...
    kind: global___Span.SpanKind.V = ...
    start_time_unix_nano: builtins.int = ...
    end_time_unix_nano: builtins.int = ...
    dropped_attributes_count: builtins.int = ...
    dropped_events_count: builtins.int = ...
    dropped_links_count: builtins.int = ...

    @property
    def attributes(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[opentelemetry.proto.common.v1.common_pb2.KeyValue]: ...

    @property
    def events(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___Span.Event]: ...

    @property
    def links(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___Span.Link]: ...

    @property
    def status(self) -> global___Status: ...

    def __init__(self,
        *,
        trace_id : builtins.bytes = ...,
        span_id : builtins.bytes = ...,
        trace_state : typing.Text = ...,
        parent_span_id : builtins.bytes = ...,
        name : typing.Text = ...,
        kind : global___Span.SpanKind.V = ...,
        start_time_unix_nano : builtins.int = ...,
        end_time_unix_nano : builtins.int = ...,
        attributes : typing.Optional[typing.Iterable[opentelemetry.proto.common.v1.common_pb2.KeyValue]] = ...,
        dropped_attributes_count : builtins.int = ...,
        events : typing.Optional[typing.Iterable[global___Span.Event]] = ...,
        dropped_events_count : builtins.int = ...,
        links : typing.Optional[typing.Iterable[global___Span.Link]] = ...,
        dropped_links_count : builtins.int = ...,
        status : typing.Optional[global___Status] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal[u"status",b"status"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"attributes",b"attributes",u"dropped_attributes_count",b"dropped_attributes_count",u"dropped_events_count",b"dropped_events_count",u"dropped_links_count",b"dropped_links_count",u"end_time_unix_nano",b"end_time_unix_nano",u"events",b"events",u"kind",b"kind",u"links",b"links",u"name",b"name",u"parent_span_id",b"parent_span_id",u"span_id",b"span_id",u"start_time_unix_nano",b"start_time_unix_nano",u"status",b"status",u"trace_id",b"trace_id",u"trace_state",b"trace_state"]) -> None: ...
global___Span = Span

class Status(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    class _DeprecatedStatusCode(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[DeprecatedStatusCode.V], builtins.type):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor = ...
        DEPRECATED_STATUS_CODE_OK = Status.DeprecatedStatusCode.V(0)
        DEPRECATED_STATUS_CODE_CANCELLED = Status.DeprecatedStatusCode.V(1)
        DEPRECATED_STATUS_CODE_UNKNOWN_ERROR = Status.DeprecatedStatusCode.V(2)
        DEPRECATED_STATUS_CODE_INVALID_ARGUMENT = Status.DeprecatedStatusCode.V(3)
        DEPRECATED_STATUS_CODE_DEADLINE_EXCEEDED = Status.DeprecatedStatusCode.V(4)
        DEPRECATED_STATUS_CODE_NOT_FOUND = Status.DeprecatedStatusCode.V(5)
        DEPRECATED_STATUS_CODE_ALREADY_EXISTS = Status.DeprecatedStatusCode.V(6)
        DEPRECATED_STATUS_CODE_PERMISSION_DENIED = Status.DeprecatedStatusCode.V(7)
        DEPRECATED_STATUS_CODE_RESOURCE_EXHAUSTED = Status.DeprecatedStatusCode.V(8)
        DEPRECATED_STATUS_CODE_FAILED_PRECONDITION = Status.DeprecatedStatusCode.V(9)
        DEPRECATED_STATUS_CODE_ABORTED = Status.DeprecatedStatusCode.V(10)
        DEPRECATED_STATUS_CODE_OUT_OF_RANGE = Status.DeprecatedStatusCode.V(11)
        DEPRECATED_STATUS_CODE_UNIMPLEMENTED = Status.DeprecatedStatusCode.V(12)
        DEPRECATED_STATUS_CODE_INTERNAL_ERROR = Status.DeprecatedStatusCode.V(13)
        DEPRECATED_STATUS_CODE_UNAVAILABLE = Status.DeprecatedStatusCode.V(14)
        DEPRECATED_STATUS_CODE_DATA_LOSS = Status.DeprecatedStatusCode.V(15)
        DEPRECATED_STATUS_CODE_UNAUTHENTICATED = Status.DeprecatedStatusCode.V(16)
    class DeprecatedStatusCode(metaclass=_DeprecatedStatusCode):
        V = typing.NewType('V', builtins.int)
    DEPRECATED_STATUS_CODE_OK = Status.DeprecatedStatusCode.V(0)
    DEPRECATED_STATUS_CODE_CANCELLED = Status.DeprecatedStatusCode.V(1)
    DEPRECATED_STATUS_CODE_UNKNOWN_ERROR = Status.DeprecatedStatusCode.V(2)
    DEPRECATED_STATUS_CODE_INVALID_ARGUMENT = Status.DeprecatedStatusCode.V(3)
    DEPRECATED_STATUS_CODE_DEADLINE_EXCEEDED = Status.DeprecatedStatusCode.V(4)
    DEPRECATED_STATUS_CODE_NOT_FOUND = Status.DeprecatedStatusCode.V(5)
    DEPRECATED_STATUS_CODE_ALREADY_EXISTS = Status.DeprecatedStatusCode.V(6)
    DEPRECATED_STATUS_CODE_PERMISSION_DENIED = Status.DeprecatedStatusCode.V(7)
    DEPRECATED_STATUS_CODE_RESOURCE_EXHAUSTED = Status.DeprecatedStatusCode.V(8)
    DEPRECATED_STATUS_CODE_FAILED_PRECONDITION = Status.DeprecatedStatusCode.V(9)
    DEPRECATED_STATUS_CODE_ABORTED = Status.DeprecatedStatusCode.V(10)
    DEPRECATED_STATUS_CODE_OUT_OF_RANGE = Status.DeprecatedStatusCode.V(11)
    DEPRECATED_STATUS_CODE_UNIMPLEMENTED = Status.DeprecatedStatusCode.V(12)
    DEPRECATED_STATUS_CODE_INTERNAL_ERROR = Status.DeprecatedStatusCode.V(13)
    DEPRECATED_STATUS_CODE_UNAVAILABLE = Status.DeprecatedStatusCode.V(14)
    DEPRECATED_STATUS_CODE_DATA_LOSS = Status.DeprecatedStatusCode.V(15)
    DEPRECATED_STATUS_CODE_UNAUTHENTICATED = Status.DeprecatedStatusCode.V(16)

    class _StatusCode(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[StatusCode.V], builtins.type):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor = ...
        STATUS_CODE_UNSET = Status.StatusCode.V(0)
        STATUS_CODE_OK = Status.StatusCode.V(1)
        STATUS_CODE_ERROR = Status.StatusCode.V(2)
    class StatusCode(metaclass=_StatusCode):
        V = typing.NewType('V', builtins.int)
    STATUS_CODE_UNSET = Status.StatusCode.V(0)
    STATUS_CODE_OK = Status.StatusCode.V(1)
    STATUS_CODE_ERROR = Status.StatusCode.V(2)

    DEPRECATED_CODE_FIELD_NUMBER: builtins.int
    MESSAGE_FIELD_NUMBER: builtins.int
    CODE_FIELD_NUMBER: builtins.int
    deprecated_code: global___Status.DeprecatedStatusCode.V = ...
    message: typing.Text = ...
    code: global___Status.StatusCode.V = ...

    def __init__(self,
        *,
        deprecated_code : global___Status.DeprecatedStatusCode.V = ...,
        message : typing.Text = ...,
        code : global___Status.StatusCode.V = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"code",b"code",u"deprecated_code",b"deprecated_code",u"message",b"message"]) -> None: ...
global___Status = Status



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import opentelemetry.proto.logs.v1.logs_pb2
import typing
import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class ExportLogsServiceRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    RESOURCE_LOGS_FIELD_NUMBER: builtins.int

    @property
    def resource_logs(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[opentelemetry.proto.logs.v1.logs_pb2.ResourceLogs]: ...

    def __init__(self,
        *,
        resource_logs : typing.Optional[typing.Iterable[opentelemetry.proto.logs.v1.logs_pb2.ResourceLogs]] = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"resource_logs",b"resource_logs"]) -> None: ...
global___ExportLogsServiceRequest = ExportLogsServiceRequest

class ExportLogsServiceResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...

    def __init__(self,
        ) -> None: ...
global___ExportLogsServiceResponse = ExportLogsServiceResponse
